/* GCC */

#include <fstream>
#include <vector>

class Number
{
public:
    enum {base = 1000*1000*1000};
private:
    std::vector<int> m_number;
    void clear()
    {
        while(!m_number.empty() && m_number.back() == 0)
            m_number.pop_back();
    }
public:
    Number() {}
    Number(unsigned long long n)
    {
        m_number.push_back(n % base);
        m_number.push_back(n / base);
        this->clear();
    }
    void operator +=(const Number& other)
    {
        int carry = 0;
        for(int i = 0;i < other.m_number.size() || carry;i++)
        {
            if(i >= m_number.size())
                m_number.push_back(0);
            m_number[i] += carry + (i < other.m_number.size() ? other.m_number[i] : 0);
            carry = m_number[i] / base;
            m_number[i] %= base;
        }
        this->clear();
    }
    friend std::ostream& operator <<(std::ostream&,const Number&);
};

std::ostream& operator <<(std::ostream& out,const Number& n)
{
    if(n.m_number.empty())
        out << 0;
    else
    {
        out << n.m_number.back();
        for(int i = n.m_number.size()-2;i >= 0;i--)
        {
            out.fill('0');
            out.width(9);
            out << n.m_number[i];
        }
    }
    return out;
}

int main()
{
    std::ifstream in("numbers.in");
    int n,m;
    in >> n >> m;
    in.close();
    std::ofstream out("numbers.out");
    if(m > 9*n)
        out << 0;
    else if(m == 9*n)
        out << 1;
    else
    {
        std::vector<std::vector<Number> > table(n,std::vector<Number>(m));
        table[0][0] = 1;
        for(int i = 1;i < n;i++)
            for(int j = 0;j < m;j++)
                for(int k = 0;k <= 9;k++)
                    if(j-k >= 0)
                        table[i][j] += table[i-1][j-k];
        Number answer;
        for(int k = 1;k <= 9;k++)
            if(m-k >= 0)
                answer += table.back()[m-k];
        out << answer;
    }
    out << std::endl;
    out.close();
}
